@@ -308,8 +308,11 @@ void Con_Init (void)
 
 	//johnfitz -- user settable console buffer size
 	i = COM_CheckParm("-consize");
-	if (i && i < com_argc-1)
-		con_buffersize = q_max(CON_MINSIZE,Q_atoi(com_argv[i+1])*1024);
+	if (i && i < com_argc-1) {
+		con_buffersize = Q_atoi(com_argv[i+1])*1024;
+		if (con_buffersize < CON_MINSIZE)
+			con_buffersize = CON_MINSIZE;
+	}
 	else
 		con_buffersize = CON_TEXTSIZE;
 	//johnfitz
@@ -467,7 +470,13 @@ void Con_DebugLog(const char *msg)
 	if (log_fd == -1)
 		return;
 
-	write(log_fd, msg, strlen(msg));
+	if (write(log_fd, msg, strlen(msg)) < 0)
+	{
+		close (log_fd);
+		log_fd = -1;
+		con_debuglog = false;
+		fprintf (stderr, "Error writing to log file\n");
+	}
 }
 
 
@@ -822,8 +831,7 @@ static const arg_completion_type_t arg_completion_types[] =
 	{ "timedemo ", &demolist }
 };
 
-static const int num_arg_completion_types =
-	sizeof(arg_completion_types)/sizeof(arg_completion_types[0]);
+static const int num_arg_completion_types = Q_COUNTOF(arg_completion_types);
 
 /*
 ============
